packproto

package
v0.0.0-...-c0337eb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 2, 2022 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Protocol

type Protocol struct {
	// contains filtered or unexported fields
}

Protocol implements the git pack protocol

func NewProtocol

func NewProtocol(w io.Writer, r io.Reader) *Protocol

NewProtocol instantiates a new protocol with the given reader and writer

func (*Protocol) ListReferences

func (proto *Protocol) ListReferences(service string, refs []*plumbing.Reference)

ListReferences writes the references in the pack protocol given the repository and service type

func (*Protocol) ReceivePack

func (proto *Protocol) ReceivePack(objstore storer.Storer) error

ReceivePack implements the git receive pack protocol

func (*Protocol) UploadPack

func (proto *Protocol) UploadPack(store storer.EncodedObjectStorer) ([]byte, error)

UploadPack implements the git upload pack protocol

Jump to