storage

package
v0.0.0-...-c0337eb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 2, 2022 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type FilesystemGitRepoStorage

type FilesystemGitRepoStorage struct {
	// contains filtered or unexported fields
}

FilesystemGitRepoStorage manages objects stores by id i.e. repo

func NewFilesystemGitRepoStorage

func NewFilesystemGitRepoStorage(dir string) *FilesystemGitRepoStorage

NewFilesystemGitRepoStorage returns an new instance of FilesystemGitRepoStorage

func (*FilesystemGitRepoStorage) GetStore

func (mos *FilesystemGitRepoStorage) GetStore(id string) storer.Storer

GetStore for the given id. Create one if it does not exist

type GitRepoStorage

type GitRepoStorage interface {
	// GetStore gets an object store given the id where the id is the namespace
	// for storage
	GetStore(string) storer.Storer
}

GitRepoStorage implements an interface to store objects for repos

type MemGitRepoStorage

type MemGitRepoStorage struct {
	// contains filtered or unexported fields
}

MemGitRepoStorage manages objects stores by id i.e. repo

func NewMemGitRepoStorage

func NewMemGitRepoStorage() *MemGitRepoStorage

NewMemGitRepoStorage returns a new instance of MemGitRepoStorage

func (*MemGitRepoStorage) GetStore

func (mos *MemGitRepoStorage) GetStore(id string) storer.Storer

GetStore for the given id. Create one if it does not exist

Jump to