Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Protocol ¶
type Protocol struct {
// contains filtered or unexported fields
}
Protocol implements the git pack protocol
func NewProtocol ¶
NewProtocol instantiates a new protocol with the given reader and writer
func (*Protocol) ListReferences ¶
ListReferences writes the references in the pack protocol given the repository and service type
func (*Protocol) ReceivePack ¶
ReceivePack implements the git receive pack protocol
func (*Protocol) UploadPack ¶
func (proto *Protocol) UploadPack(store storer.EncodedObjectStorer) ([]byte, error)
UploadPack implements the git upload pack protocol
Click to show internal directories.
Click to hide internal directories.