Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FilesystemGitRepoStorage ¶
type FilesystemGitRepoStorage struct {
// contains filtered or unexported fields
}
FilesystemGitRepoStorage manages objects stores by id i.e. repo
func NewFilesystemGitRepoStorage ¶
func NewFilesystemGitRepoStorage(dir string) *FilesystemGitRepoStorage
NewFilesystemGitRepoStorage returns an new instance of FilesystemGitRepoStorage
type GitRepoStorage ¶
type GitRepoStorage interface {
// GetStore gets an object store given the id where the id is the namespace
// for storage
GetStore(string) storer.Storer
}
GitRepoStorage implements an interface to store objects for repos
type MemGitRepoStorage ¶
type MemGitRepoStorage struct {
// contains filtered or unexported fields
}
MemGitRepoStorage manages objects stores by id i.e. repo
func NewMemGitRepoStorage ¶
func NewMemGitRepoStorage() *MemGitRepoStorage
NewMemGitRepoStorage returns a new instance of MemGitRepoStorage
Click to show internal directories.
Click to hide internal directories.